<?php
namespace WOOCPTProductsTiles;

use WOOCPTProductsTiles\PageSettings\Page_Settings;
define( "WOOCPT_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "WOOCPT_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class WOOCPTProductsTilesBWD {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function woocpt_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'woocpt_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function woocpt_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'woocpt_the_service_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}
		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/woocpt-products.php' );
	}

	public function woocpt_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WOOCPTProducts() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/super-products-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function woocpt_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdwoocpt_creative_products_category',
			[
				'title' => esc_html__( 'WooC Products Tiles', 'wooc-products-tiles' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function woocpt_all_assets_for_the_public(){
		$all_css_js_file = array(
            'woocpt-all-min' => array('woocpt_path_define'=>WOOCPT_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/all.min.css'),
            'woocpt-style' => array('woocpt_path_define'=>WOOCPT_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/woocpt_css.css'),
        );
		$all_js_js_file = array(
            'woocpt-ferdaussk' => array('woocpt_js_path_define'=>WOOCPT_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/js/ferdaussk.js'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['woocpt_path_define'], null, '1.0', 'all');
        }
        foreach($all_js_js_file as $js_handle => $js_fileinfo){
            wp_enqueue_script( $js_handle, $js_fileinfo['woocpt_js_path_define'], ['jquery'], '1.0', true);
        }
	}
	public function woocpt_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'woocpt_products_admin_icon_css' => array('woocpt_path_admin_define'=>WOOCPT_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['woocpt_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'woocpt_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'woocpt_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'woocpt_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'woocpt_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'woocpt_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
WOOCPTProductsTilesBWD::instance();